@@ -23,8 +23,14 @@
  * ======================================================================== */
 
 #pragma once
-
+#include <QObject>
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/ActionReply>
+#include <KAuth/HelperSupport>
+#else
 #include <KAuth>
+#endif
 
 using namespace KAuth;
 
